==> jc-1.4.0.tar.gz: java/lang/StackOverflowError.h <==
// public class java.lang.StackOverflowError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 42dd90d695900d80 java_lang_StackOverflowError
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c7632ae877826bc6 java_lang_VirtualMachineError

// header file dependencies
// @dep_header java_lang_VirtualMachineError

#include "java/lang/VirtualMachineError.h"

#ifndef _JC_java_lang_StackOverflowError_H_
#define _JC_java_lang_StackOverflowError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_StackOverflowError$sub_refs	_jc_java_lang_StackOverflowError$sub_refs;
typedef struct _jc_java_lang_StackOverflowError$sub_nonrefs	_jc_java_lang_StackOverflowError$sub_nonrefs;
typedef struct _jc_java_lang_StackOverflowError$refs	_jc_java_lang_StackOverflowError$refs;
typedef struct _jc_java_lang_StackOverflowError$nonrefs	_jc_java_lang_StackOverflowError$nonrefs;
typedef struct _jc_java_lang_StackOverflowError$object	_jc_java_lang_StackOverflowError$object;

typedef struct _jc_java_lang_StackOverflowError$fields_struct	_jc_java_lang_StackOverflowError$fields_struct;
typedef const struct _jc_java_lang_StackOverflowError$vmethods	_jc_java_lang_StackOverflowError$vmethods;
typedef const struct _jc_java_lang_StackOverflowError$vtable	_jc_java_lang_StackOverflowError$vtable;
typedef const struct _jc_java_lang_StackOverflowError$vtype	_jc_java_lang_StackOverflowError$vtype;

// Class fields structure
struct _jc_java_lang_StackOverflowError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_StackOverflowError$fields_struct _jc_java_lang_StackOverflowError$class_fields;

// Constructors
extern void _jc_java_lang_StackOverflowError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_StackOverflowError$object *);
extern void _jc_java_lang_StackOverflowError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_StackOverflowError$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_StackOverflowError$vmethods {
};

// Vtable
struct _jc_java_lang_StackOverflowError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_VirtualMachineError$vmethods	java_lang_VirtualMachineError;
	_jc_java_lang_StackOverflowError$vmethods	java_lang_StackOverflowError;
};

// Vtype
struct _jc_java_lang_StackOverflowError$vtype {
	_jc_type			type;
	_jc_java_lang_StackOverflowError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_StackOverflowError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_StackOverflowError$refs {
    _jc_java_lang_StackOverflowError$sub_refs	java_lang_StackOverflowError;
    _jc_java_lang_VirtualMachineError$sub_refs	java_lang_VirtualMachineError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_StackOverflowError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_StackOverflowError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_VirtualMachineError$sub_nonrefs	java_lang_VirtualMachineError;
    _jc_java_lang_StackOverflowError$sub_nonrefs	java_lang_StackOverflowError;
};

// Object instance structure
struct _jc_java_lang_StackOverflowError$object {
	_jc_java_lang_StackOverflowError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_StackOverflowError$vtype	*vtype;
	_jc_java_lang_StackOverflowError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_StackOverflowError$vtype _jc_java_lang_StackOverflowError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_StackOverflowError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_StackOverflowError$class_object;

#endif	/* _JC_java_lang_StackOverflowError_H_ */

==> jc-1.4.6.tar.gz: java/lang/StackOverflowError.h <==
// public class java.lang.StackOverflowError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 42dd90d695900d80 java_lang_StackOverflowError
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c7632ae877826bc6 java_lang_VirtualMachineError

// header file dependencies
// @dep_header java_lang_VirtualMachineError

#include "java/lang/VirtualMachineError.h"

#ifndef _JC_java_lang_StackOverflowError_H_
#define _JC_java_lang_StackOverflowError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_StackOverflowError$sub_refs	_jc_java_lang_StackOverflowError$sub_refs;
typedef struct _jc_java_lang_StackOverflowError$sub_nonrefs	_jc_java_lang_StackOverflowError$sub_nonrefs;
typedef struct _jc_java_lang_StackOverflowError$refs	_jc_java_lang_StackOverflowError$refs;
typedef struct _jc_java_lang_StackOverflowError$nonrefs	_jc_java_lang_StackOverflowError$nonrefs;
typedef struct _jc_java_lang_StackOverflowError$object	_jc_java_lang_StackOverflowError$object;

typedef struct _jc_java_lang_StackOverflowError$fields_struct	_jc_java_lang_StackOverflowError$fields_struct;
typedef const struct _jc_java_lang_StackOverflowError$vmethods	_jc_java_lang_StackOverflowError$vmethods;
typedef const struct _jc_java_lang_StackOverflowError$vtable	_jc_java_lang_StackOverflowError$vtable;
typedef const struct _jc_java_lang_StackOverflowError$vtype	_jc_java_lang_StackOverflowError$vtype;

// Class fields structure
struct _jc_java_lang_StackOverflowError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_StackOverflowError$fields_struct _jc_java_lang_StackOverflowError$class_fields;

// Constructors
extern void _jc_java_lang_StackOverflowError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_StackOverflowError$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_StackOverflowError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_StackOverflowError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_StackOverflowError$vmethods {
};

// Vtable
struct _jc_java_lang_StackOverflowError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_VirtualMachineError$vmethods	java_lang_VirtualMachineError;
	_jc_java_lang_StackOverflowError$vmethods	java_lang_StackOverflowError;
};

// Vtype
struct _jc_java_lang_StackOverflowError$vtype {
	_jc_type			type;
	_jc_java_lang_StackOverflowError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_StackOverflowError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_StackOverflowError$refs {
    _jc_java_lang_StackOverflowError$sub_refs	java_lang_StackOverflowError;
    _jc_java_lang_VirtualMachineError$sub_refs	java_lang_VirtualMachineError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_StackOverflowError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_StackOverflowError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_VirtualMachineError$sub_nonrefs	java_lang_VirtualMachineError;
    _jc_java_lang_StackOverflowError$sub_nonrefs	java_lang_StackOverflowError;
};

// Object instance structure
struct _jc_java_lang_StackOverflowError$object {
	_jc_java_lang_StackOverflowError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_StackOverflowError$vtype	*vtype;
	_jc_java_lang_StackOverflowError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_StackOverflowError$vtype _jc_java_lang_StackOverflowError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_StackOverflowError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_StackOverflowError$class_object;

#endif	/* _JC_java_lang_StackOverflowError_H_ */
